@@ -413,7 +413,7 @@ render_total_label (WINDOW * win, GDashModule * module_data, int y)
   (void) win_h;
 
   sprintf (s, "Total: %d/%d", total, ht_size);
-  draw_header (win, s, "%s", y, win_w - strlen (s) - 2, win_w, HIGHLIGHT);
+  draw_header (win, s, "%s", y, win_w - strlen (s) - 2, win_w, HIGHLIGHT, 0);
   free (s);
 }
 
@@ -431,7 +431,7 @@ render_bars (WINDOW * win, GDashModule * module_data, int y, int *x, int idx,
 
   bar = get_bars (module_data->data[idx].hits, module_data->max_hits, *x);
   if (selected)
-    draw_header (win, bar, "%s", y, *x, w, HIGHLIGHT);
+    draw_header (win, bar, "%s", y, *x, w, HIGHLIGHT, 0);
   else
     mvwprintw (win, y, *x, "%s", bar);
   free (bar);
@@ -455,11 +455,11 @@ render_data (WINDOW * win, GDashModule * module_data, int y, int *x, int idx,
   if (selected) {
     if (module_data->module == HOSTS && module_data->data[idx].is_subitem) {
       padded_data = left_pad_str (data, *x);
-      draw_header (win, padded_data, "%s", y, 0, w, HIGHLIGHT);
+      draw_header (win, padded_data, "%s", y, 0, w, HIGHLIGHT, 0);
       free (padded_data);
     } else {
       draw_header (win, module == VISITORS ? buf : data, "%s", y, *x, w,
-                   HIGHLIGHT);
+                   HIGHLIGHT, 0);
     }
   } else {
     wattron (win, COLOR_PAIR (style[module].color_hits));
@@ -487,7 +487,7 @@ render_method (WINDOW * win, GDashModule * module_data, int y, int *x,
     return;
 
   if (selected) {
-    draw_header (win, method, "%s", y, *x, w, HIGHLIGHT);
+    draw_header (win, method, "%s", y, *x, w, HIGHLIGHT, 0);
   } else {
     wattron (win, A_BOLD | COLOR_PAIR (style[module].color_method));
     mvwprintw (win, y, *x, "%s", method);
@@ -512,7 +512,7 @@ render_protocol (WINDOW * win, GDashModule * module_data, int y, int *x,
     return;
 
   if (selected) {
-    draw_header (win, protocol, "%s", y, *x, w, HIGHLIGHT);
+    draw_header (win, protocol, "%s", y, *x, w, HIGHLIGHT, 0);
   } else {
     wattron (win, COLOR_PAIR (style[module].color_protocol));
     mvwprintw (win, y, *x, "%s", protocol);
@@ -536,7 +536,7 @@ render_usecs (WINDOW * win, GDashModule * module_data, int y, int *x, int idx,
 
   if (selected) {
     draw_header (win, module_data->data[idx].serve_time, "%9s", y, *x, w,
-                 HIGHLIGHT);
+                 HIGHLIGHT, 0);
   } else {
     wattron (win, A_BOLD | COLOR_PAIR (style[module].color_usecs));
     mvwprintw (win, y, *x, "%9s", module_data->data[idx].serve_time);
@@ -561,7 +561,7 @@ render_bandwidth (WINDOW * win, GDashModule * module_data, int y, int *x,
 
   if (selected) {
     draw_header (win, module_data->data[idx].bandwidth, "%11s", y, *x, w,
-                 HIGHLIGHT);
+                 HIGHLIGHT, 0);
   } else {
     wattron (win, A_BOLD | COLOR_PAIR (style[module].color_bw));
     mvwprintw (win, y, *x, "%11s", module_data->data[idx].bandwidth);
@@ -590,7 +590,7 @@ render_percent (WINDOW * win, GDashModule * module_data, int y, int *x,
 
   if (selected) {
     char *percent = float_to_str (module_data->data[idx].percent);
-    draw_header (win, percent, "%s%%", y, *x, w, HIGHLIGHT);
+    draw_header (win, percent, "%s%%", y, *x, w, HIGHLIGHT, 0);
     free (percent);
   } else {
     wattron (win, A_BOLD | COLOR_PAIR (style[module].color_percent));
@@ -625,7 +625,7 @@ render_hits (WINDOW * win, GDashModule * module_data, int y, int *x, int idx,
 
   if (selected) {
     hits = int_to_str (module_data->data[idx].hits);
-    draw_header (win, hits, "  %s", y, 0, w, HIGHLIGHT);
+    draw_header (win, hits, "  %s", y, 0, w, HIGHLIGHT, 0);
     free (hits);
   } else {
     wattron (win, COLOR_PAIR (style[module].color_hits));
@@ -666,7 +666,7 @@ render_content (WINDOW * win, GDashModule * module_data, int *y, int *offset,
       hd = xmalloc (snprintf (NULL, 0, "%d - %s", k, module_data->head) + 1);
       sprintf (hd, "%d - %s", k, module_data->head);
 
-      draw_header (win, hd, " %s", (*y), 0, w, 1);
+      draw_header (win, hd, " %s", (*y), 0, w, 1, 0);
       free (hd);
 
       render_total_label (win, module_data, (*y));
@@ -675,7 +675,7 @@ render_content (WINDOW * win, GDashModule * module_data, int *y, int *offset,
     }
     /* description */
     else if ((i % size) == DASH_DESC_POS)
-      draw_header (win, module_data->desc, " %s", (*y)++, 0, w, 2);
+      draw_header (win, module_data->desc, " %s", (*y)++, 0, w, 2, 0);
     /* blank lines */
     else if ((i % size) == DASH_EMPTY_POS || (i % size) == size - 1)
       (*y)++;
@@ -742,8 +742,7 @@ display_content (WINDOW * win, GLog * logger, GDash * dash,
     }
 
     /* Every module other than VISITORS, GEO_LOCATION, BROWSERS and OS
-     * will use total req as base
-     */
+     * will use total req as base */
     switch (i) {
 #ifdef HAVE_LIBGEOIP
      case GEO_LOCATION:
@@ -791,7 +790,7 @@ regexp_init (regex_t * regex, const char *pattern)
   /* something went wrong */
   if (rc != 0) {
     regerror (rc, regex, buf, sizeof (buf));
-    draw_header (stdscr, buf, "%s", y - 1, 0, x, WHITE_RED);
+    draw_header (stdscr, buf, "%s", y - 1, 0, x, WHITE_RED, 0);
     refresh ();
     return 1;
   }
@@ -881,7 +880,7 @@ perform_next_find (GHolder * h, GScrolling * scrolling)
       rc = regexec (&regex, data, 0, NULL, 0);
       if (rc != 0 && rc != REG_NOMATCH) {
         regerror (rc, &regex, buf, sizeof (buf));
-        draw_header (stdscr, buf, "%s", y - 1, 0, x, WHITE_RED);
+        draw_header (stdscr, buf, "%s", y - 1, 0, x, WHITE_RED, 0);
         refresh ();
         regfree (&regex);
         return 1;
@@ -930,8 +929,8 @@ render_find_dialog (WINDOW * main_win, GScrolling * scrolling)
   win = newwin (h, w, (y - h) / 2, (x - w) / 2);
   keypad (win, TRUE);
   wborder (win, '|', '|', '-', '-', '+', '+', '+', '+');
-  draw_header (win, FIND_HEAD, " %s", 1, 1, w - 2, 1);
-  draw_header (win, FIND_DESC, " %s", 2, 1, w - 2, 2);
+  draw_header (win, FIND_HEAD, " %s", 1, 1, w - 2, 1, 0);
+  draw_header (win, FIND_DESC, " %s", 2, 1, w - 2, 2, 0);
 
   find_t.icase = 0;
   query = input_string (win, 4, 2, w - 3, "", 1, &find_t.icase);
