@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2009-2013 by Gerardo Orellana <goaccess@prosoftcorp.com>
+ * Copyright (C) 2009-2014 by Gerardo Orellana <goaccess@prosoftcorp.com>
  * GoAccess - An Ncurses apache weblog analyzer & interactive viewer
  *
  * This program is free software; you can redistribute it and/or
@@ -22,10 +22,14 @@
 #include <config.h>
 #endif
 
-#ifdef HAVE_LIBNCURSESW
-#include <ncursesw/curses.h>
-#else
+#ifdef HAVE_NCURSESW_NCURSES_H
+#include <ncursesw/ncurses.h>
+#elif HAVE_NCURSES_NCURSES_H
+#include <ncurses/ncurses.h>
+#elif HAVE_NCURSES_H
 #include <ncurses.h>
+#elif HAVE_CURSES_H
+#include <curses.h>
 #endif
 
 #ifndef GMENU_H_INCLUDED
@@ -33,9 +37,9 @@
 
 enum ACTION
 {
-   REQ_DOWN,
-   REQ_UP,
-   REQ_SEL
+  REQ_DOWN,
+  REQ_UP,
+  REQ_SEL
 };
 
 typedef struct GMenu_ GMenu;
@@ -43,32 +47,30 @@ typedef struct GItem_ GItem;
 
 struct GItem_
 {
-   char *name;
-   int checked;
+  char *name;
+  int checked;
 };
 
 struct GMenu_
 {
-   WINDOW *win;
+  WINDOW *win;
 
-   int count;
-   int size;
-   int idx;
-   int start;
-   int h;
-   int w;
-   int x;
-   int y;
-   unsigned short multiple;
-   unsigned short selectable;
-   unsigned short status;
-   GItem *items;
+  int count;
+  int size;
+  int idx;
+  int start;
+  int h;
+  int w;
+  int x;
+  int y;
+  unsigned short multiple;
+  unsigned short selectable;
+  unsigned short status;
+  GItem *items;
 };
 
 GMenu *new_gmenu (WINDOW * parent, int h, int w, int y, int x);
 int post_gmenu (GMenu * menu);
-void draw_menu_item (GMenu * menu, char *s, int x, int y, int w, int color,
-                     int checked);
 void gmenu_driver (GMenu * menu, int c);
 
 #endif
