@@ -40,6 +40,7 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <signal.h>
 
 #ifdef HAVE_LIBTOKYOCABINET
 #include "tcabinet.h"
@@ -146,58 +147,7 @@ house_keeping (void)
 #endif
 
   /* STORAGE */
-#ifdef HAVE_LIBTOKYOCABINET
-#ifdef HAVE_LIBGEOIP
-  tc_db_close (ht_countries, DB_COUNTRIES);
-#endif
-#ifdef TCB_BTREE
-  tc_db_close (ht_general_stats, DB_GENERAL_STATS);
-#endif
-  tc_db_close (ht_browsers, DB_BROWSERS);
-  tc_db_close (ht_date_bw, DB_DATE_BW);
-  tc_db_close (ht_file_bw, DB_FILE_BW);
-  tc_db_close (ht_file_serve_usecs, DB_FILE_SERVE_USECS);
-  tc_db_close (ht_host_bw, DB_HOST_BW);
-  tc_db_close (ht_hosts_agents, DB_HOST_AGENTS);
-  tc_db_close (ht_hosts, DB_HOSTS);
-  tc_db_close (ht_host_serve_usecs, DB_HOST_SERVE_USECS);
-  tc_db_close (ht_keyphrases, DB_KEYPHRASES);
-  tc_db_close (ht_not_found_requests, DB_NOT_FOUND_REQUESTS);
-  tc_db_close (ht_os, DB_OS);
-  tc_db_close (ht_referrers, DB_REFERRERS);
-  tc_db_close (ht_referring_sites, DB_REFERRING_SITES);
-  tc_db_close (ht_request_keys, DB_REQUEST_KEYS);
-  tc_db_close (ht_request_methods, DB_REQUEST_METHODS);
-  tc_db_close (ht_request_protocols, DB_REQUEST_PROTOCOLS);
-  tc_db_close (ht_requests, DB_REQUESTS);
-  tc_db_close (ht_requests_static, DB_REQUESTS_STATIC);
-  tc_db_close (ht_status_code, DB_STATUS_CODE);
-  tc_db_close (ht_unique_vis, DB_UNIQUE_VIS);
-  tc_db_close (ht_unique_visitors, DB_UNIQUE_VISITORS);
-#else
-#ifdef HAVE_LIBGEOIP
-  g_hash_table_foreach (ht_countries, free_countries, NULL);
-#endif
-  g_hash_table_foreach (ht_os, free_os, NULL);
-  g_hash_table_foreach (ht_browsers, free_browser, NULL);
-
-  g_hash_table_destroy (ht_browsers);
-  g_hash_table_destroy (ht_countries);
-  g_hash_table_destroy (ht_date_bw);
-  g_hash_table_destroy (ht_file_bw);
-  g_hash_table_destroy (ht_host_bw);
-  g_hash_table_destroy (ht_hosts);
-  g_hash_table_destroy (ht_keyphrases);
-  g_hash_table_destroy (ht_not_found_requests);
-  g_hash_table_destroy (ht_os);
-  g_hash_table_destroy (ht_referrers);
-  g_hash_table_destroy (ht_referring_sites);
-  g_hash_table_destroy (ht_requests);
-  g_hash_table_destroy (ht_requests_static);
-  g_hash_table_destroy (ht_status_code);
-  g_hash_table_destroy (ht_unique_vis);
-  g_hash_table_destroy (ht_unique_visitors);
-#endif
+  free_storage ();
 
   /* LOGGER */
   free (logger);
@@ -363,7 +313,7 @@ render_screens (void)
   generate_time ();
   chg = logger->process - logger->offset;
 
-  draw_header (stdscr, "", "%s", row - 1, 0, col, 0);
+  draw_header (stdscr, "", "%s", row - 1, 0, col, 0, 0);
   wattron (stdscr, COLOR_PAIR (COL_WHITE));
   mvaddstr (row - 1, 1, "[F1]Help [O]pen detail view");
   mvprintw (row - 1, 30, "%d - %s", chg, asctime (now_tm));
@@ -716,8 +666,7 @@ get_keys (void)
        /* file has changed */
        if (size2 != size1) {
          if (!(fp = fopen (conf.ifile, "r")))
-           error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                          "Unable to read log file.");
+           FATAL ("Unable to read log file %s.", strerror (errno));
          if (!fseeko (fp, size1, SEEK_SET))
            while (fgets (buf, LINE_BUFFER, fp) != NULL)
              parse_log (&logger, buf, -1);
@@ -782,7 +731,6 @@ set_locale (void)
     setlocale (LC_CTYPE, loc_ctype);
   else
     setlocale (LC_CTYPE, "");
-  setlocale (LC_NUMERIC, "");
 }
 
 static void
@@ -798,11 +746,28 @@ parse_cmd_line (int argc, char **argv)
     cmd_help ();
 }
 
+#if defined(__GLIBC__)
+static void
+setup_signal_handlers (void)
+{
+  struct sigaction act;
+  sigemptyset (&act.sa_mask);
+  act.sa_flags = 0;
+  act.sa_handler = sigsegv_handler;
+
+  sigaction (SIGSEGV, &act, NULL);
+}
+#endif
+
 int
 main (int argc, char **argv)
 {
   int quit = 0;
 
+#if defined(__GLIBC__)
+  setup_signal_handlers ();
+#endif
+
   /* command line/config options */
   verify_global_config (argc, argv);
   parse_conf_file (&argc, &argv);
@@ -858,15 +823,13 @@ out:
   if (conf.load_from_disk)
     set_general_stats ();
   else if (!quit && parse_log (&logger, NULL, -1))
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   "Error while processing file");
+    FATAL ("Error while processing file");
 
   logger->offset = logger->process;
 
   /* no valid entries to process from the log */
   if ((logger->process == 0) || (logger->process == logger->invalid))
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   "Nothing valid to process.");
+    FATAL ("Nothing valid to process.");
 
   /* init reverse lookup thread */
   gdns_init ();
