@@ -963,7 +963,7 @@ print_html_hosts (FILE * fp, GHolder * h, int process)
     if (ag != NULL) {
       ptr_value = (char *) ag;
 
-      delims = count_occurrences (ptr_value, '|');
+      delims = count_matches (ptr_value, '|');
       /* round-up + padding */
       alloc = ((strlen (ptr_value) + 300 - 1) / 300) + delims + 1;
       agents = xmalloc (alloc * sizeof (GAgents));
@@ -1311,7 +1311,8 @@ output_html (GLog * logger, GHolder * holder)
   print_html_generic (fp, holder + REFERRING_SITES, logger->process);
   print_html_generic (fp, holder + KEYPHRASES, logger->process);
 #ifdef HAVE_LIBGEOIP
-  print_html_geolocation (fp, holder + GEO_LOCATION, logger->process);
+  print_html_geolocation (fp, holder + GEO_LOCATION,
+                          get_ht_size (ht_unique_visitors));
 #endif
   print_html_status (fp, holder + STATUS_CODES, logger->process);
 
