@@ -333,70 +333,81 @@ free_logger (GLogItem * glog)
   free (glog);
 }
 
-#define SPC_BASE16_TO_10(x) (((x) >= '0' && (x) <= '9') ? ((x) - '0') \
-                               : (toupper((x)) - 'A' + 10))
+#define BASE16_TO_10(x) (((x) >= '0' && (x) <= '9') ? ((x) - '0') : \
+    (toupper((x)) - 'A' + 10))
+
 static char *
-spc_decode_url (char *url)
+decode_url (char *url)
 {
   char *out, *ptr;
   const char *c;
 
-  if (!(out = ptr = xstrdup (url)))
-    return 0;
+  if ((url == NULL) || (*url == '\0'))
+    return NULL;
+
+  out = ptr = xstrdup (url);
   for (c = url; *c; c++) {
     if (*c != '%' || !isxdigit (c[1]) || !isxdigit (c[2]))
       *ptr++ = *c;
     else {
-      *ptr++ = (SPC_BASE16_TO_10 (c[1]) * 16) + (SPC_BASE16_TO_10 (c[2]));
+      *ptr++ = (BASE16_TO_10 (c[1]) * 16) + (BASE16_TO_10 (c[2]));
       c += 2;
     }
   }
   *ptr = 0;
+  strip_newlines (out);
+
   return trim_str (out);
 }
 
-/* process keyphrases used on Google search, Google cache, and
- * Google translate. */
+/* Process keyphrases from Google search, cache, and translate.
+ * Note that the referer hasn't been decoded at the entry point
+ * since there could be '&' within the search query. */
 static int
 process_keyphrases (char *ref)
 {
-  char *r, *ptr, *p, *dec, *pch;
+  char *r, *ptr, *pch, *referer;
+  int encoded = 0;
 
   if (!(strstr (ref, "http://www.google.")) &&
       !(strstr (ref, "http://webcache.googleusercontent.com/")) &&
       !(strstr (ref, "http://translate.googleusercontent.com/")))
     return 1;
 
+  /* webcache.googleusercontent */
   if ((r = strstr (ref, "/+&")) != NULL)
     return 1;
+  /* webcache.googleusercontent */
   else if ((r = strstr (ref, "/+")) != NULL)
     r += 2;
+  /* webcache.googleusercontent */
   else if ((r = strstr (ref, "q=cache:")) != NULL) {
     pch = strchr (r, '+');
     if (pch)
       r += pch - r + 1;
-  } else if ((r = strstr (ref, "&q=")) != NULL ||
-             (r = strstr (ref, "?q=")) != NULL)
+  }
+  /* www.google.* or translate.googleusercontent */
+  else if ((r = strstr (ref, "&q=")) != NULL ||
+           (r = strstr (ref, "?q=")) != NULL)
     r += 3;
   else if ((r = strstr (ref, "%26q%3D")) != NULL ||
            (r = strstr (ref, "%3Fq%3D")) != NULL)
-    r += 7;
+    encoded = 1, r += 7;
   else
     return 1;
-  dec = spc_decode_url (r);
-  if ((ptr = strstr (dec, "%26")) != NULL || (ptr = strchr (dec, '&')) != NULL)
+
+  if (!encoded && (ptr = strchr (r, '&')) != NULL)
+    *ptr = '\0';
+  else if (encoded && (ptr = strstr (r, "%26")) != NULL)
     *ptr = '\0';
 
-  p = dec;
-  if (p[0] == '\0') {
-    if (dec != NULL)
-      free (dec);
+  referer = decode_url (r);
+  if (referer == NULL || *referer == '\0')
     return 1;
-  }
-  p = char_replace (p, '+', ' ');
-  process_generic_data (ht_keyphrases, trim_str (dec));
-  if (dec != NULL)
-    free (dec);
+
+  referer = char_replace (referer, '+', ' ');
+  process_generic_data (ht_keyphrases, trim_str (referer));
+  free (referer);
 
   return 0;
 }
@@ -406,17 +417,21 @@ static void
 process_referrers (char *referrer)
 {
   char *ref;
-  char url[512] = "";
+  char url[REF_SITE_LEN] = "";
 
   if (referrer == NULL)
     return;
 
-  ref = spc_decode_url (referrer);
   /* extract the host part, i.e., www.foo.com */
-  if (sscanf (ref, "%*[^/]%*[/]%[^/]", url) == 1)
+  if (sscanf (referrer, "%*[^/]%*[/]%[^/]", url) == 1)
     process_generic_data (ht_referring_sites, url);
-  process_generic_data (ht_referrers, ref);
   process_keyphrases (referrer);
+
+  ref = decode_url (referrer);
+  if (ref == NULL || *ref == '\0')
+    return;
+
+  process_generic_data (ht_referrers, ref);
   free (ref);
 }
 
@@ -431,8 +446,7 @@ process_unique_data (char *host, char *date, char *agent)
   char country[COUNTRY_LEN] = "";
 #endif
 
-  char *a = NULL;
-  char *browser_key = NULL, *browser = NULL;
+  char *a = NULL, *browser_key = NULL, *browser = NULL;
   char *os_key = NULL, *opsys = NULL;
 
   char visitor_key[UKEY_BUFFER];
@@ -443,11 +457,10 @@ process_unique_data (char *host, char *date, char *agent)
   (visitor_key)[sizeof (visitor_key) - 1] = '\0';
   free (a);
 
-  /*
-   * Check if the unique visitor key exists, if not,
-   * process hit as unique visitor. Includes, BROWSERS, OSs, VISITORS.
-   */
+  /* Check if the unique visitor key exists, if not,
+   * process hit as unique visitor. Includes, BROWSERS, OSs, VISITORS. */
   if (process_generic_data (ht_unique_visitors, visitor_key) == -1) {
+    process_generic_data (ht_unique_vis, date);
     browser_key = xstrdup (agent);
     os_key = xstrdup (agent);
 
@@ -470,15 +483,6 @@ process_unique_data (char *host, char *date, char *agent)
       process_geolocation (ht_countries, country, continent, city);
     }
 #endif
-
-    if ((date = strchr (visitor_key, '|')) != NULL) {
-      char *tmp_date = NULL;
-      tmp_date = clean_date (++date);
-      if (tmp_date != NULL) {
-        process_generic_data (ht_unique_vis, tmp_date);
-        free (tmp_date);
-      }
-    }
   }
 
   if (browser != NULL)
@@ -539,27 +543,21 @@ append_protocol_to_request (char **key, const char *protocol)
 static int
 verify_static_content (char *req)
 {
-  char *nul = req + strlen (req);
+  char *nul = req + strlen (req), *ext = NULL;
+  int elen = 0, i;
 
-  if (strlen (req) < 5)
+  if (strlen (req) < conf.static_file_max_len)
     return 0;
-  if (!memcmp (nul - 4, ".jpg", 4) || !memcmp (nul - 4, ".JPG", 4) ||
-      !memcmp (nul - 4, ".png", 4) || !memcmp (nul - 4, ".PNG", 4) ||
-      !memcmp (nul - 4, ".pdf", 4) || !memcmp (nul - 4, ".PDF", 4) ||
-      !memcmp (nul - 3, ".js", 3) || !memcmp (nul - 3, ".JS", 3) ||
-      !memcmp (nul - 4, ".map", 4) || !memcmp (nul - 4, ".MAP", 4) ||
-      !memcmp (nul - 4, ".gif", 4) || !memcmp (nul - 4, ".GIF", 4) ||
-      !memcmp (nul - 4, ".css", 4) || !memcmp (nul - 4, ".CSS", 4) ||
-      !memcmp (nul - 4, ".ico", 4) || !memcmp (nul - 4, ".ICO", 4) ||
-      !memcmp (nul - 4, ".txt", 4) || !memcmp (nul - 4, ".TXT", 4) ||
-      !memcmp (nul - 4, ".swf", 4) || !memcmp (nul - 4, ".SWF", 4) ||
-      !memcmp (nul - 5, ".jpeg", 5) || !memcmp (nul - 5, ".JPEG", 5) ||
-      !memcmp (nul - 5, ".woff", 5) || !memcmp (nul - 5, ".WOFF", 5) ||
-      !memcmp (nul - 4, ".eot", 4) || !memcmp (nul - 4, ".EOT", 4) ||
-      !memcmp (nul - 4, ".svg", 4) || !memcmp (nul - 4, ".SVG", 4) ||
-      !memcmp (nul - 4, ".ttf", 4) || !memcmp (nul - 4, ".TTF", 4) ||
-      !memcmp (nul - 4, ".dae", 4) || !memcmp (nul - 4, ".DAE", 4))
-    return 1;
+
+  for (i = 0; i < conf.static_file_idx; ++i) {
+    ext = conf.static_files[i];
+    if (ext == NULL || *ext == '\0')
+      continue;
+
+    elen = strlen (ext);
+    if (!memcmp (nul - elen, ext, elen))
+      return 1;
+  }
   return 0;
 }
 
@@ -567,7 +565,7 @@ static char *
 parse_req (char *line, GLogItem * glog)
 {
   const char *lookfor = NULL;
-  char *reqs, *req_l = NULL, *req_r = NULL;
+  char *req, *request, *req_l = NULL, *req_r = NULL;
   char *method = NULL, *protocol = NULL;
   ptrdiff_t req_len;
 
@@ -579,6 +577,7 @@ parse_req (char *line, GLogItem * glog)
       (lookfor = "DELETE ", req_l = strstr (line, lookfor)) != NULL ||
       (lookfor = "TRACE ", req_l = strstr (line, lookfor)) != NULL ||
       (lookfor = "CONNECT ", req_l = strstr (line, lookfor)) != NULL ||
+      (lookfor = "PATCH", req_l = strstr (line, lookfor)) != NULL ||
       (lookfor = "options ", req_l = strstr (line, lookfor)) != NULL ||
       (lookfor = "get ", req_l = strstr (line, lookfor)) != NULL ||
       (lookfor = "head ", req_l = strstr (line, lookfor)) != NULL ||
@@ -586,8 +585,8 @@ parse_req (char *line, GLogItem * glog)
       (lookfor = "put ", req_l = strstr (line, lookfor)) != NULL ||
       (lookfor = "delete ", req_l = strstr (line, lookfor)) != NULL ||
       (lookfor = "trace ", req_l = strstr (line, lookfor)) != NULL ||
-      (lookfor = "connect ", req_l = strstr (line, lookfor)) != NULL) {
-
+      (lookfor = "connect ", req_l = strstr (line, lookfor)) != NULL ||
+      (lookfor = "patch", req_l = strstr (line, lookfor)) != NULL) {
     /* didn't find it - weird  */
     if ((req_r = strstr (line, " HTTP/1.0")) == NULL &&
         (req_r = strstr (line, " HTTP/1.1")) == NULL)
@@ -600,9 +599,9 @@ parse_req (char *line, GLogItem * glog)
     if (req_len <= 0)
       return alloc_string ("-");
 
-    reqs = xmalloc (req_len + 1);
-    strncpy (reqs, req_l, req_len);
-    reqs[req_len] = 0;
+    req = xmalloc (req_len + 1);
+    strncpy (req, req_l, req_len);
+    req[req_len] = 0;
 
     if (conf.append_method) {
       method = trim_str (xstrdup (lookfor));
@@ -616,9 +615,15 @@ parse_req (char *line, GLogItem * glog)
       glog->protocol = protocol;
     }
   } else
-    reqs = alloc_string (line);
+    req = alloc_string (line);
 
-  return reqs;
+  request = decode_url (req);
+  if (request != NULL && *request != '\0') {
+    free (req);
+    return request;
+  }
+
+  return req;
 }
 
 static int
@@ -634,6 +639,7 @@ invalid_method (const char *token)
            (lookfor = "DELETE", !memcmp (token, lookfor, 6)) ||
            (lookfor = "TRACE", !memcmp (token, lookfor, 5)) ||
            (lookfor = "CONNECT", !memcmp (token, lookfor, 7)) ||
+           (lookfor = "PATCH", !memcmp (token, lookfor, 5)) ||
            (lookfor = "options", !memcmp (token, lookfor, 7)) ||
            (lookfor = "get", !memcmp (token, lookfor, 3)) ||
            (lookfor = "head", !memcmp (token, lookfor, 4)) ||
@@ -641,7 +647,8 @@ invalid_method (const char *token)
            (lookfor = "put", !memcmp (token, lookfor, 3)) ||
            (lookfor = "delete", !memcmp (token, lookfor, 6)) ||
            (lookfor = "trace", !memcmp (token, lookfor, 5)) ||
-           (lookfor = "connect", !memcmp (token, lookfor, 7)));
+           (lookfor = "connect", !memcmp (token, lookfor, 7)) ||
+           (lookfor = "patch", !memcmp (token, lookfor, 5)));
 }
 
 static int
@@ -654,11 +661,14 @@ invalid_protocol (const char *token)
 }
 
 static char *
-parse_string (char **str, char end)
+parse_string (char **str, char end, int cnt)
 {
+  int idx = 0;
   char *pch = *str, *p;
   do {
-    if (*pch == end || *pch == '\0') {
+    if (*pch == end)
+      idx++;
+    if ((*pch == end && cnt == idx) || *pch == '\0') {
       size_t len = (pch - *str + 1);
       p = xmalloc (len);
       memcpy (p, *str, (len - 1));
@@ -706,7 +716,9 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'd':
          if (glog->date)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         /* parse date format including dates containing spaces,
+          * i.e., syslog date format (Jul 15 20:10:56) */
+         tkn = parse_string (&str, p[1], count_matches (date_format, ' ') + 1);
          if (tkn == NULL)
            return 1;
          end = strptime (tkn, date_format, &tm);
@@ -720,7 +732,7 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'h':
          if (glog->host)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            return 1;
          if (invalid_ipaddr (tkn)) {
@@ -733,7 +745,7 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'm':
          if (glog->method)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            return 1;
          if (invalid_method (tkn)) {
@@ -746,16 +758,18 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'U':
          if (glog->req)
            return 1;
-         tkn = parse_string (&str, p[1]);
-         if (tkn == NULL)
+         tkn = parse_string (&str, p[1], 1);
+         if (tkn == NULL || *tkn == '\0')
            return 1;
-         glog->req = tkn;
+         if ((glog->req = decode_url (tkn)) == NULL)
+           return 1;
+         free (tkn);
          break;
          /* request protocol */
        case 'H':
          if (glog->protocol)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            return 1;
          if (invalid_protocol (tkn)) {
@@ -768,7 +782,7 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'r':
          if (glog->req)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            return 1;
          glog->req = parse_req (tkn, glog);
@@ -778,7 +792,7 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 's':
          if (glog->status)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            return 1;
          strtol (tkn, &sEnd, 10);
@@ -792,7 +806,7 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'b':
          if (glog->resp_size)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            return 1;
          bandw = strtol (tkn, &bEnd, 10);
@@ -806,7 +820,7 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'R':
          if (glog->ref)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            tkn = alloc_string ("-");
          if (tkn != NULL && *tkn == '\0') {
@@ -819,13 +833,11 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'u':
          if (glog->agent)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn != NULL && *tkn != '\0') {
-           /*
-            * Make sure the user agent is decoded (i.e.: CloudFront)
-            * and replace all '+' with ' ' (i.e.: w3c)
-            */
-           glog->agent = char_replace (spc_decode_url (tkn), '+', ' ');
+           /* Make sure the user agent is decoded (i.e.: CloudFront)
+            * and replace all '+' with ' ' (i.e.: w3c) */
+           glog->agent = char_replace (decode_url (tkn), '+', ' ');
            free (tkn);
            break;
          } else if (tkn != NULL && *tkn == '\0') {
@@ -846,7 +858,7 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
          if (strstr (fmt, "%D") != NULL)
            break;
 
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            return 1;
          if (strchr (tkn, '.') != NULL)
@@ -868,7 +880,7 @@ parse_format (GLogItem * glog, const char *fmt, const char *date_format,
        case 'D':
          if (glog->serve_time)
            return 1;
-         tkn = parse_string (&str, p[1]);
+         tkn = parse_string (&str, p[1], 1);
          if (tkn == NULL)
            return 1;
          serve_time = strtoull (tkn, &bEnd, 10);
@@ -929,35 +941,34 @@ process_log (GLog * logger, char *line, int test)
 
   glog = init_log_item (logger);
   if (parse_format (glog, conf.log_format, conf.date_format, line) == 1) {
-    free_logger (glog);
     logger->invalid++;
 
 #ifdef TCB_BTREE
     process_generic_data (ht_general_stats, "failed_requests");
 #endif
-    return 0;
+    goto cleanup;
   }
 
   /* must have the following fields */
   if (glog->host == NULL || glog->date == NULL || glog->status == NULL ||
       glog->req == NULL) {
-    free_logger (glog);
     logger->invalid++;
-    return 0;
+    goto cleanup;
   }
 
-  if (test) {
-    free_logger (glog);
-    return 0;
-  }
+  if (test)
+    goto cleanup;
 
   convert_date (buf, glog->date, conf.date_format, "%Y%m%d", DATE_LEN);
   if (buf == NULL)
-    return 0;
+    goto cleanup;
 
   /* ignore host */
-  if (conf.ignore_host != NULL && strcmp (glog->host, conf.ignore_host) == 0)
-    return 0;
+  if (conf.ignore_ip_idx && ip_in_range (glog->host))
+    goto cleanup;
+  /* ignore crawlers */
+  if (conf.ignore_crawlers && is_crawler (glog->agent))
+    goto cleanup;
 
   /* agent will be null in cases where %u is not specified */
   if (glog->agent == NULL)
@@ -1022,8 +1033,11 @@ process_log (GLog * logger, char *line, int test)
   process_request_meta (ht_general_stats, "bandwidth", glog->resp_size);
 #endif
 
+cleanup:
   free_logger (glog);
-  free (req_key);
+  if (req_key != NULL)
+    free (req_key);
+
   return 0;
 }
 
@@ -1036,12 +1050,10 @@ parse_log (GLog ** logger, char *tail, int n)
   int i = 0, test = -1 == n ? 0 : 1;
 
   if (conf.date_format == NULL || *conf.date_format == '\0')
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   "No date format was found on your conf file.");
+    FATAL ("No date format was found on your conf file.");
 
   if (conf.log_format == NULL || *conf.log_format == '\0')
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   "No log format was found on your conf file.");
+    FATAL ("No log format was found on your conf file.");
 
   if (tail != NULL) {
     if (process_log ((*logger), tail, test))
@@ -1056,7 +1068,7 @@ parse_log (GLog ** logger, char *tail, int n)
 
   /* make sure we can open the log (if not reading from stdin) */
   if (!(*logger)->piping && (fp = fopen (conf.ifile, "r")) == NULL)
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__, strerror (errno));
+    FATAL ("%s", strerror (errno));
 
   while (fgets (line, LINE_BUFFER, fp) != NULL) {
     if (n >= 0 && i++ == n)
@@ -1081,8 +1093,7 @@ int
 test_format (GLog * logger)
 {
   if (parse_log (&logger, NULL, 20))
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   "Error while processing file");
+    FATAL ("Error while processing file");
 
   if ((logger->process == 0) || (logger->process == logger->invalid))
     return 1;
