@@ -26,6 +26,7 @@
 #define BW_HASHTABLES   3
 #define KEY_FOUND       1
 #define KEY_NOT_FOUND  -1
+#define REF_SITE_LEN    512
 
 #include "commons.h"
 
@@ -67,6 +68,7 @@ typedef struct GRawData_
   int size;                     /* total num of items on ht */
 } GRawData;
 
+/* *INDENT-OFF* */
 GLog *init_log (void);
 GLogItem *init_log_item (GLog * logger);
 GRawData *new_grawdata (void);
@@ -93,5 +95,6 @@ int parse_log (GLog ** logger, char *tail, int n);
 int test_format (GLog * logger);
 void free_raw_data (GRawData * raw_data);
 void reset_struct (GLog * logger);
+/* *INDENT-ON* */
 
 #endif
