@@ -24,6 +24,8 @@
 #include <stdint.h>
 
 #define MAX_LINE_CONF 512
+#define MAX_EXTENSIONS 64
+#define MAX_IGNORE_IPS 64
 
 typedef enum
 {
@@ -67,26 +69,31 @@ typedef struct GConf_
   char *geoip_city_data;
   char *iconfigfile;
   char *ifile;
-  char *ignore_host;
+  char *ignore_ips[MAX_IGNORE_IPS];
   char *log_format;
   char *output_format;
+  char *static_files[MAX_EXTENSIONS];
   int append_method;
   int append_protocol;
   int bandwidth;
   int color_scheme;
   int enable_html_resolver;
   int geo_db;
+  int ignore_crawlers;
+  int ignore_ip_idx;
   int ignore_qstr;
   int list_agents;
   int load_conf_dlg;
+  int load_global_config;
   int mouse_support;
   int no_color;
-  int load_global_config;
   int no_progress;
   int output_html;
   int real_os;
   int serve_usecs;
   int skip_term_resolver;
+  int static_file_idx;
+  size_t static_file_max_len;
 
   /* TokyoCabinet */
   char *db_path;
