@@ -135,18 +135,14 @@ tc_db_create (const char *dbname)
   /* set the caching parameters of a B+ tree database object */
   if (!tcbdbsetcache (bdb, lcnum, ncnum)) {
     free (path);
-    LOG_DEBUG (("Unable to set TCB cache.\n\n"));
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   "Unable to set TCB cache");
+    FATAL ("Unable to set TCB cache");
   }
 
   LOG_DEBUG (("xmmap: %d\n", conf.xmmap));
   /* set the size of the extra mapped memory */
   if (conf.xmmap > 0 && !tcbdbsetxmsiz (bdb, conf.xmmap)) {
     free (path);
-    LOG_DEBUG (("Unable to set TCB xmmap.\n\n"));
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   "Unable to set TCB xmmap");
+    FATAL ("Unable to set TCB xmmap.");
   }
 
   lmemb = conf.tune_lmemb > 0 ? conf.tune_lmemb : TC_LMEMB;
@@ -178,9 +174,7 @@ tc_db_create (const char *dbname)
     free (path);
     ecode = tcbdbecode (bdb);
 
-    LOG_DEBUG (("%s\n\n", tcbdberrmsg (ecode)));
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   tcbdberrmsg (ecode));
+    FATAL ("%s", tcbdberrmsg (ecode));
   }
   free (path);
 
@@ -255,6 +249,38 @@ init_storage (void)
 /* *INDENT-ON* */
 }
 
+void
+free_storage (void)
+{
+#ifdef HAVE_LIBGEOIP
+  tc_db_close (ht_countries, DB_COUNTRIES);
+#endif
+#ifdef TCB_BTREE
+  tc_db_close (ht_general_stats, DB_GENERAL_STATS);
+#endif
+  tc_db_close (ht_browsers, DB_BROWSERS);
+  tc_db_close (ht_date_bw, DB_DATE_BW);
+  tc_db_close (ht_file_bw, DB_FILE_BW);
+  tc_db_close (ht_file_serve_usecs, DB_FILE_SERVE_USECS);
+  tc_db_close (ht_host_bw, DB_HOST_BW);
+  tc_db_close (ht_hosts_agents, DB_HOST_AGENTS);
+  tc_db_close (ht_hosts, DB_HOSTS);
+  tc_db_close (ht_host_serve_usecs, DB_HOST_SERVE_USECS);
+  tc_db_close (ht_keyphrases, DB_KEYPHRASES);
+  tc_db_close (ht_not_found_requests, DB_NOT_FOUND_REQUESTS);
+  tc_db_close (ht_os, DB_OS);
+  tc_db_close (ht_referrers, DB_REFERRERS);
+  tc_db_close (ht_referring_sites, DB_REFERRING_SITES);
+  tc_db_close (ht_request_keys, DB_REQUEST_KEYS);
+  tc_db_close (ht_request_methods, DB_REQUEST_METHODS);
+  tc_db_close (ht_request_protocols, DB_REQUEST_PROTOCOLS);
+  tc_db_close (ht_requests, DB_REQUESTS);
+  tc_db_close (ht_requests_static, DB_REQUESTS_STATIC);
+  tc_db_close (ht_status_code, DB_STATUS_CODE);
+  tc_db_close (ht_unique_vis, DB_UNIQUE_VIS);
+  tc_db_close (ht_unique_visitors, DB_UNIQUE_VISITORS);
+}
+
 /* Close the database handle */
 #ifdef TCB_BTREE
 int
@@ -270,8 +296,7 @@ tc_db_close (void *db, const char *dbname)
   /* close the database */
   if (!tcbdbclose (bdb)) {
     ecode = tcbdbecode (bdb);
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   tcbdberrmsg (ecode));
+    FATAL ("%s", tcbdberrmsg (ecode));
   }
   /* delete the object */
   tcbdbdel (bdb);
@@ -395,8 +420,7 @@ tc_db_put (void *db, const char *k, void *v, uint32_t v_size)
   TCBDB *bdb = db;
   if (!tcbdbput (bdb, k, strlen (k), v, v_size)) {
     ecode = tcbdbecode (bdb);
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   tcbdberrmsg (ecode));
+    FATAL ("%s", tcbdberrmsg (ecode));
   }
 #else
   TCMDB *mdb = db;
@@ -424,8 +448,7 @@ tc_db_put_str (void *db, const char *k, const char *v)
   TCBDB *bdb = db;
   if (!tcbdbput2 (bdb, k, v)) {
     ecode = tcbdbecode (bdb);
-    error_handler (__PRETTY_FUNCTION__, __FILE__, __LINE__,
-                   tcbdberrmsg (ecode));
+    FATAL ("%s", tcbdberrmsg (ecode));
   }
 #else
   TCMDB *mdb = db;
@@ -701,7 +724,7 @@ get_bandwidth (char *k, GModule module)
 }
 
 char *
-get_request_meta (const char *k, GReqMeta meta)
+get_request_meta (const char *k, GReqMeta meta_req)
 {
 #ifdef TCB_BTREE
   TCBDB *db = NULL;
@@ -710,7 +733,7 @@ get_request_meta (const char *k, GReqMeta meta)
 #endif
   void *value;
 
-  switch (meta) {
+  switch (meta_req) {
    case REQUEST:
      db = ht_request_keys;
      break;
