@@ -34,13 +34,13 @@
 #define MINS             60000000ULL
 #define HOUR             3600000000ULL
 
+/* *INDENT-OFF* */
+#include <stdint.h>
+
 char *alloc_string (const char *str);
 char *char_repeat (int n, char c);
 char *char_replace (char *str, char o, char n);
-char *clean_date (char *s);
-char *clean_month (char *s);
-char *convert_date (char *result, char *data, const char *from, const char *to,
-                    int size);
+char *convert_date (char *result, char *data, const char *from, const char *to, int size);
 char *deblank (char *str);
 char *escape_str (const char *src);
 char *filesize_str (unsigned long long log_size);
@@ -59,11 +59,16 @@ char *unescape_str (const char *src);
 char *usecs_to_str (unsigned long long usec);
 const char *verify_status_code (char *str);
 const char *verify_status_code_type (const char *str);
-int count_occurrences (const char *s1, char c);
+int count_matches (const char *s1, char c);
 int intlen (int num);
 int invalid_ipaddr (char *str);
+int ip_in_range (const char *ip);
 off_t file_size (const char *filename);
+uint32_t ip_to_binary (const char *ip);
+void strip_newlines (char *str);
 void str_to_upper (char *s);
 void xstrncpy (char *dest, const char *source, const size_t dest_size);
 
+/* *INDENT-ON* */
+
 #endif
